/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.dao;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityTransaction;
import javax.persistence.NoResultException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.iai.ilcd.model.common.MultiLanguageString;
import de.iai.ilcd.model.datastock.DataStock;
import de.iai.ilcd.persistence.PersistenceUtil;

/**
 * 
 * @author clemens.duepmeier
 */
public class DataStockDao {

	private static final Logger logger = LoggerFactory.getLogger(ContactDao.class);

	private DataStock getDataStock(Long id) {
		EntityManager em = PersistenceUtil.getEntityManager();
		return em.find(DataStock.class, id);
	}

	public DataStock getDataStock(long parseLong) {
		return this.getDataStock(new Long(parseLong));
	}

	public DataStock getDataStock(MultiLanguageString name) {
		return getDataStock(name.getDefaultValue());
	}

	private DataStock getDataStock(String name) {
		EntityManager em = PersistenceUtil.getEntityManager();
		DataStock stock = null;
		try {
			stock = (DataStock) em.createQuery("select ds from DataStock ds where ds.name.defaultValue=:name")
					.setParameter("name", name).getSingleResult();
		} catch (NoResultException e) {
			// do nothing; we just return null
		}
		return stock;
	}

	public List<DataStock> getDataStocks() {
		EntityManager em = PersistenceUtil.getEntityManager();

		List<DataStock> stocks = new ArrayList<DataStock>();
		stocks = em.createQuery("select ds from DataStock ds order by ds.name.defaultValue").getResultList();
		return stocks;
	}

	public void persist(DataStock stock) throws PersistException {
		EntityManager em = PersistenceUtil.getEntityManager();
		EntityTransaction tx = em.getTransaction();

		try {
			tx.begin();
			em.persist(stock);
			tx.commit();
		} catch (Exception e) {
			if (tx.isActive())
				tx.rollback();
			throw new PersistException("Cannot persist DataStock object " + stock.getName().getValue(), e);
		}
	}

	public void remove(DataStock stock) throws DeleteDataSetException {
		if (stock == null || stock.getId() == null) {
			return;
		}
		EntityManager em = PersistenceUtil.getEntityManager();
		EntityTransaction tx = em.getTransaction();
		try {
			tx.begin();
			DataStock toRemove = em.find(stock.getClass(), stock.getId());
			if (toRemove != null) {
				em.remove(toRemove);
			}
			tx.commit();
		} catch (Exception e) {
			logger.error("Cannot remove data stock {} from database", stock.getName().getDefaultValue(), e);
			if (tx.isActive()) {
				tx.rollback();
			}
			throw new DeleteDataSetException("Cannot remove data stock " + stock.getName().getDefaultValue());
		}
	}

	public void merge(DataStock stock) throws MergeException {
		if ((stock == null) || (stock.getId() == null)) {
			return;
		}
		EntityManager em = PersistenceUtil.getEntityManager();
		EntityTransaction tx = em.getTransaction();
		try {
			tx.begin();
			em.merge(stock);
			tx.commit();
		} catch (Exception e) {
			if (tx.isActive()) {
				tx.rollback();
			}
			throw new MergeException("Cannot merge changes of data stock " + stock.getName().getDefaultValue()
					+ " into database");
		}
	}
}
