/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.dao;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import de.iai.ilcd.model.security.UserGroup;
import de.iai.ilcd.persistence.PersistenceUtil;

/**
 * 
 * @author clemens.duepmeier
 */
public class UserGroupDao {

	public List<UserGroup> getGroups() {
		EntityManager em = PersistenceUtil.getEntityManager();

		List<UserGroup> groups = (List<UserGroup>) em.createQuery("select g from UserGroup g").getResultList();

		return groups;
	}

	public UserGroup getGroup(String groupName) {
		EntityManager em = PersistenceUtil.getEntityManager();

		UserGroup group = null;
		try {
			group = (UserGroup) em.createQuery("select g from UserGroup g where g.groupName=:groupName")
					.setParameter("groupName", groupName).getSingleResult();
		} catch (NoResultException e) {
			// we do nothing here; just return null
		}
		return group;
	}

	public UserGroup getGroup(long groupId) {
		EntityManager em = PersistenceUtil.getEntityManager();

		UserGroup group = (UserGroup) em.find(UserGroup.class, Long.valueOf(groupId));

		return group;
	}

	public void persist(UserGroup group) throws Exception {
		EntityManager em = PersistenceUtil.getEntityManager();

		try {
			em.getTransaction().begin();
			em.persist(group);
			em.getTransaction().commit();
		} catch (Exception e) {
			em.getTransaction().rollback();
			throw e;
		}
	}

	public void remove(UserGroup group) {
		EntityManager em = PersistenceUtil.getEntityManager();
		try {
			em.getTransaction().begin();
			UserGroup managed = em.find(UserGroup.class, group.getId());
			em.remove(managed);
			em.getTransaction().commit();

		} catch (Exception e) {
		}
	}

	public void merge(UserGroup group) {
		EntityManager em = PersistenceUtil.getEntityManager();
		try {
			em.getTransaction().begin();
			em.merge(group);
			em.getTransaction().commit();

		} catch (Exception e) {
		}
	}
}
