/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.datastock;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import javax.persistence.AssociationOverride;
import javax.persistence.AttributeOverride;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;

import de.iai.ilcd.model.common.MultiLanguageString;
import de.iai.ilcd.model.common.MultiLanguageText;
import de.iai.ilcd.model.contact.Contact;
import de.iai.ilcd.model.flow.Flow;
import de.iai.ilcd.model.flowproperty.FlowProperty;
import de.iai.ilcd.model.process.Process;
import de.iai.ilcd.model.source.Source;
import de.iai.ilcd.model.unitgroup.UnitGroup;

/**
 * 
 * @author clemens.duepmeier
 */
@Entity
public class DataStock implements Serializable {

	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private Long id;

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "name"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "datastock_names", joinColumns = @JoinColumn(name = "datastock_id", referencedColumnName = "ID")))
	protected MultiLanguageString name = new MultiLanguageString();

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "title"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "datastock_titles", joinColumns = @JoinColumn(name = "datastock_id", referencedColumnName = "ID")))
	protected MultiLanguageString title = new MultiLanguageString();

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "description"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "datastock_descriptions", joinColumns = @JoinColumn(name = "datastock_id", referencedColumnName = "ID")))
	protected MultiLanguageText description = new MultiLanguageText();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<Process> processes = new HashSet<Process>();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<Flow> flows = new HashSet<Flow>();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<FlowProperty> flowProperties = new HashSet<FlowProperty>();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<UnitGroup> unitGroups = new HashSet<UnitGroup>();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<Source> sources = new HashSet<Source>();

	@ManyToMany(cascade = CascadeType.ALL)
	protected Set<Contact> contacts = new HashSet<Contact>();

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public MultiLanguageText getDescription() {
		return description;
	}

	public void setDescription(MultiLanguageText description) {
		this.description = description;
	}

	public MultiLanguageString getName() {
		return name;
	}

	public void setName(MultiLanguageString name) {
		this.name = name;
	}

	public MultiLanguageString getTitle() {
		return title;
	}

	public void setTitle(MultiLanguageString title) {
		this.title = title;
	}

	public Set<Contact> getContacts() {
		return contacts;
	}

	private void setContacts(Set<Contact> contacts) {
		this.contacts = contacts;
	}

	public Set<FlowProperty> getFlowProperties() {
		return flowProperties;
	}

	private void setFlowProperties(Set<FlowProperty> flowProperties) {
		this.flowProperties = flowProperties;
	}

	public Set<Flow> getFlows() {
		return flows;
	}

	private void setFlows(Set<Flow> flows) {
		this.flows = flows;
	}

	public Set<Process> getProcesses() {
		return processes;
	}

	private void setProcesses(Set<Process> processes) {
		this.processes = processes;
	}

	public void addProcess(Process process) {
		if (!processes.contains(process)) {
			process.addToDataStock(this);
			processes.add(process);
		}
	}

	public void deleteProcess(Process process) {
		if (processes.contains(process)) {
			process.removeFromStock(this);
			processes.remove(process);
		}
	}

	public void deleteAllProcesses() {
		List<Process> all = new ArrayList<Process>();
		all.addAll(processes);

		for (Process process : all)
			this.deleteProcess(process);
	}

	public Set<Source> getSources() {
		return sources;
	}

	private void setSources(Set<Source> sources) {
		this.sources = sources;
	}

	public Set<UnitGroup> getUnitGroups() {
		return unitGroups;
	}

	private void setUnitGroups(Set<UnitGroup> unitGroups) {
		this.unitGroups = unitGroups;
	}

	@Override
	public int hashCode() {
		int hash = 0;
		hash += (name != null ? name.hashCode() : 0);
		return hash;
	}

	@Override
	public boolean equals(Object object) {
		// TODO: Warning - this method won't work in the case the id fields are not set
		if (!(object instanceof DataStock)) {
			return false;
		}
		DataStock other = (DataStock) object;
		if ((this.name == null && other.name != null) || (this.name != null && !this.name.equals(other.name))) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		return "de.iai.ilcd.model.datastock.DataStock[name=" + name.getValue() + "]";
	}

}
