/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.flow;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.AssociationOverride;
import javax.persistence.AttributeOverride;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import de.fzk.iai.ilcd.service.model.IFlowVO;
import de.fzk.iai.ilcd.service.model.enums.TypeOfFlowValue;
import de.iai.ilcd.model.common.Classification;
import de.iai.ilcd.model.common.DataSet;
import de.iai.ilcd.model.common.MultiLanguageString;

/**
 * 
 * @author clemens.duepmeier
 */
@Entity
@Table(uniqueConstraints = @UniqueConstraint(columnNames = { "UUID", "MAJORVERSION", "MINORVERSION", "SUBMINORVERSION" }))
public class Flow extends DataSet implements Serializable, IFlowVO {

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "synonyms"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "flow_synonyms", joinColumns = @JoinColumn(name = "flow_id", referencedColumnName = "ID")))
	protected MultiLanguageString synonyms = new MultiLanguageString();

	@Enumerated(EnumType.STRING)
	private TypeOfFlowValue type;

	@ManyToOne(cascade = CascadeType.ALL)
	protected Classification categorization = new Classification();

	protected String casNumber;

	protected String sumFormula;

	@ManyToOne(cascade = CascadeType.ALL)
	protected FlowPropertyDescription referenceProperty;

	@OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
	Set<FlowPropertyDescription> propertyDescriptions = new HashSet<FlowPropertyDescription>();

	@Override
	public String getCasNumber() {
		return casNumber;
	}

	public void setCasNumber(String casNumber) {
		this.casNumber = casNumber;
	}

	public Classification getCategorization() {
		return categorization;
	}

	@Override
	public Classification getFlowCategorization() {
		return this.getCategorization();
	}

	public void setCategorization(Classification categorization) {
		this.categorization = categorization;
	}

	public Set<FlowPropertyDescription> getPropertyDescriptions() {
		return propertyDescriptions;
	}

	protected void setPropertyDescriptions(Set<FlowPropertyDescription> propertyDescriptions) {
		this.propertyDescriptions = propertyDescriptions;
	}

	public void addPropertDesription(FlowPropertyDescription propertyDescription) {
		if (!propertyDescriptions.contains(propertyDescription))
			propertyDescriptions.add(propertyDescription);
	}

	public FlowPropertyDescription getReferenceProperty() {
		return referenceProperty;
	}

	@Override
	public FlowPropertyDescription getReferenceFlowProperty() {
		return this.getReferenceProperty();
	}

	public void setReferenceProperty(FlowPropertyDescription referenceProperty) {
		this.referenceProperty = referenceProperty;
	}

	@Override
	public String getSumFormula() {
		return sumFormula;
	}

	public void setSumFormula(String sumFormula) {
		this.sumFormula = sumFormula;
	}

	@Override
	public MultiLanguageString getSynonyms() {
		return synonyms;
	}

	public void setSynonyms(MultiLanguageString synonyms) {
		this.synonyms = synonyms;
	}

	@Override
	public TypeOfFlowValue getType() {
		return type;
	}

	public void setType(TypeOfFlowValue type) {
		this.type = type;
	}

	@Override
	public String toString() {
		return "de.iai.ilcd.model.flow.Flow[id=" + id + "]";
	}

	public boolean isElementaryFlow() {
		return TypeOfFlowValue.ELEMENTARY_FLOW.equals(this.getType());
	}

}
