/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.process;

import java.io.Serializable;

import javax.persistence.AssociationOverride;
import javax.persistence.AttributeOverride;
import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.Embedded;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;

import de.fzk.iai.ilcd.service.model.common.ILString;
import de.iai.ilcd.model.common.MultiLanguageString;

/**
 * 
 * @author clemens.duepmeier
 */
@Embeddable
public class ProcessName implements Serializable {

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "baseName"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "processname_base", joinColumns = @JoinColumn(name = "process_id", referencedColumnName = "ID")))
	MultiLanguageString basePart = new MultiLanguageString();

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "routeName"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "processname_route", joinColumns = @JoinColumn(name = "process_id", referencedColumnName = "ID")))
	MultiLanguageString routePart = new MultiLanguageString();

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "locationName"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "processname_location", joinColumns = @JoinColumn(name = "process_id", referencedColumnName = "ID")))
	MultiLanguageString locationPart = new MultiLanguageString();

	@Embedded
	@AttributeOverride(name = "defaultValue", column = @Column(name = "unitName"))
	@AssociationOverride(name = "lStringMap", joinTable = @JoinTable(name = "processname_unit", joinColumns = @JoinColumn(name = "process_id", referencedColumnName = "ID")))
	MultiLanguageString unitPart = new MultiLanguageString();

	public ProcessName() {
	}

	public ProcessName(MultiLanguageString basePart, MultiLanguageString routePart, MultiLanguageString locationPart,
			MultiLanguageString unitPart) {
		if (basePart != null) {
			this.basePart = basePart;
		}
		if (routePart != null) {
			this.routePart = routePart;
		}
		if (locationPart != null) {
			this.locationPart = locationPart;
		}
		if (unitPart != null) {
			this.unitPart = unitPart;
		}
	}

	public MultiLanguageString getBasePart() {
		return basePart;
	}

	public void setBasePart(MultiLanguageString basePart) {
		this.basePart = basePart;
	}

	public MultiLanguageString getLocationPart() {
		return locationPart;
	}

	public void setLocationPart(MultiLanguageString locationPart) {
		this.locationPart = locationPart;
	}

	public MultiLanguageString getRoutePart() {
		return routePart;
	}

	public void setRoutePart(MultiLanguageString routePart) {
		this.routePart = routePart;
	}

	public MultiLanguageString getUnitPart() {
		return unitPart;
	}

	public void setUnitPart(MultiLanguageString unitPart) {
		this.unitPart = unitPart;
	}

	public String getName() {
		StringBuffer name = new StringBuffer();

		if (basePart != null && basePart.getDefaultValue() != null) {
			name.append(basePart.getDefaultValue());
		}
		if (routePart != null && routePart.getDefaultValue() != null) {
			name.append(";" + routePart.getDefaultValue());
		}
		if (locationPart != null && locationPart.getDefaultValue() != null) {
			name.append(";" + locationPart.getDefaultValue());
		}
		if (unitPart != null && unitPart.getDefaultValue() != null) {
			name.append(";" + unitPart.getDefaultValue());
		}
		return name.toString();

	}

	public MultiLanguageString getFullName() {
		MultiLanguageString joinedName = new MultiLanguageString(this.getName());
		for (ILString lString : basePart.getLStrings()) {
			String language = lString.getLang();
			if (language == null)
				continue;
			String baseValue = lString.getValue();
			StringBuilder joinedValue = new StringBuilder();

			if (baseValue != null) {
				joinedValue.append(baseValue);
			}
			if (routePart != null && routePart.getValue(language) != null) {
				joinedValue.append(";").append(routePart.getValue(language));
			}
			if (locationPart != null && locationPart.getValue(language) != null) {
				joinedValue.append(";").append(locationPart.getValue(language));
			}
			if (unitPart != null && unitPart.getValue(language) != null) {
				joinedValue.append(";").append(unitPart.getValue(language));
			}

			joinedName.addLString(language, joinedValue.toString());

		}

		return joinedName;
	}
}
