/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.security;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToMany;

/**
 * 
 * @author clemens.duepmeier
 */
@Entity
public class UserGroup implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private Long id;

	@Column(nullable = false, unique = true)
	String groupName;

	@ManyToMany(cascade = { CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REFRESH, CascadeType.DETACH }) // Does not contain CascadeType.REMOVE
	List<User> users = new ArrayList<User>();

	@Enumerated(EnumType.STRING)
	@ElementCollection
	private List<SecurityRole> roles = new ArrayList<SecurityRole>();

	public UserGroup() {

	}

	public UserGroup(String groupName) {
		this.groupName = groupName;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getGroupName() {
		return groupName;
	}

	public void setGroupName(String groupName) {
		this.groupName = groupName;
	}

	public List<User> getUsers() {
		return users;
	}

	protected void setUsers(List<User> users) {
		this.users = users;
	}

	public void addUser(User user) {
		if (!users.contains(user)) {
			users.add(user);
			user.addToGroup(this);
		}
	}

	public void deleteUser(User user) {
		if (users.contains(user)) {
			users.remove(user);
			user.removeFromGroup(this);
		}
	}

	public void removeAllUser() {
		List<User> allUsers = new ArrayList<User>();
		allUsers.addAll(users);
		for (User user : allUsers) {
			user.removeFromGroup(this); // will also remove it locally but also group from user
		}
	}

	public List<SecurityRole> getRoles() {
		return roles;
	}

	protected void setRoles(List<SecurityRole> roles) {
		this.roles = roles;
	}

	public void addRole(SecurityRole role) {
		if (!roles.contains(role))
			roles.add(role);
	}

	public void deleteRole(SecurityRole role) {
		if (roles.contains(role))
			roles.remove(role);
	}

	public boolean hasRole(SecurityRole role) {
		if (roles.contains(role))
			return true;

		return false;
	}

	@Override
	public int hashCode() {
		int hash = 0;
		hash += (groupName != null ? groupName.hashCode() : 0);
		return hash;
	}

	@Override
	public boolean equals(Object object) {
		// TODO: Warning - this method won't work in the case the id fields are not set
		if (!(object instanceof UserGroup)) {
			return false;
		}
		UserGroup other = (UserGroup) object;
		if (this.groupName != null && other.getGroupName() != null && this.groupName.equals(other.getGroupName())) {
			return true;
		}
		return false;
	}

	@Override
	public String toString() {
		return "de.iai.ilcd.model.security.Group=[groupName:" + groupName + "]";
	}

}
