/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.model.unitgroup;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import de.fzk.iai.ilcd.service.model.IUnitGroupVO;
import de.iai.ilcd.model.common.DataSet;

/**
 * 
 * @author clemens.duepmeier
 */
@Entity
@Table(uniqueConstraints = @UniqueConstraint(columnNames = { "UUID", "MAJORVERSION", "MINORVERSION", "SUBMINORVERSION" }))
public class UnitGroup extends DataSet implements Serializable, IUnitGroupVO {

	@ManyToOne
	Unit referenceUnit;

	@OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
	@OrderBy("internalId")
	Set<Unit> units = new HashSet<Unit>();

	public UnitGroup() {

	}

	public UnitGroup(String name) {
		this.getName().setDefaultValue(name);
	}

	public Set<Unit> getUnits() {
		return units;
	}

	/**
	 * Convenience method for returning units as List in order to user p:dataList (primefaces)
	 * 
	 * @return List of units
	 */
	public List<Unit> getUnitsAsList() {
		return new ArrayList<Unit>(this.getUnits());
	}

	protected void setUnits(Set<Unit> units) {
		this.units = units;
	}

	public void addUnit(Unit unit) {
		units.add(unit);
	}

	public Unit getReferenceUnit() {
		return referenceUnit;
	}

	@Override
	public String getDefaultUnit() {
		return referenceUnit.getName();
	}

	public void setReferenceUnit(Unit referenceUnit) {
		this.referenceUnit = referenceUnit;
	}

}
