/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.webgui.controller.admin;

import java.io.Serializable;

import javax.faces.application.FacesMessage;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.iai.ilcd.model.dao.DataStockDao;
import de.iai.ilcd.model.dao.PersistException;
import de.iai.ilcd.model.datastock.DataStock;

/**
 * 
 * @author clemens.duepmeier
 */
@ManagedBean
@ViewScoped
public class StockHandler implements Serializable {

	private static final Logger logger = LoggerFactory.getLogger(StockHandler.class);

	private DataStock stock = new DataStock();

	/** Creates a new instance of NodeHandler */
	public StockHandler() {
		// check if the page was called with a request parameter specifying the current user
		String stockId = FacesContext.getCurrentInstance().getExternalContext().getRequestParameterMap().get("stockId");
		if (stockId != null) {
			DataStockDao stockDao = new DataStockDao();
			DataStock existingStock = stockDao.getDataStock(Long.parseLong(stockId));
			if (existingStock != null) {
				stock = existingStock;
				logger.info("found stock with name {} and stockId {}", stock.getName().getValue(), stock.getId());
			}
		}
	}

	public DataStock getStock() {
		return stock;
	}

	public void setDataStock(DataStock stock) {
		this.stock = stock;
	}

	public void createStock() {
		DataStockDao dao = new DataStockDao();
		String statusMessage;

		DataStock existingStock = dao.getDataStock(stock.getName());
		if (existingStock != null) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_WARN,
					"Warning: A data stock with this name already exists; choose another name", "");
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
			return;
		}

		try {
			dao.persist(stock);
		} catch (PersistException ex) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_ERROR,
					"Error: Could not save data stock to database", ex.getMessage());
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
			return;
		}

		// everything went well
		FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_INFO, "New data stock created", "");
		FacesContext.getCurrentInstance().addMessage("info", facesMsg);

	}

	public void changeStock() {
		DataStockDao dao = new DataStockDao();
		String statusMessage;

		DataStock existingStock = dao.getDataStock(stock.getName());
		if (existingStock == null) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_WARN, "A data stock with the name "
					+ stock.getName().getValue() + " does not exist", "");
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
			return;
		}
		try {
			logger.info("merge data stock with name {} and id {}", stock.getName().getDefaultValue(), stock.getId());
			dao.merge(stock);
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_INFO, "Saved changes to data stock", "");
			FacesContext.getCurrentInstance().addMessage("info", facesMsg);
		} catch (Exception e) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_WARN,
					"There were some erros while saving the data; please try again", "");
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
		}

	}
}
