/*******************************************************************************
 * Copyright (c) 2011 Karlsruhe Institute of Technology (KIT) - Institute for 
 * Applied Computer Science (IAI). 
 * 
 * This file is part of soda4LCA - the Service-Oriented Life Cycle Data Store.
 * 
 * soda4LCA is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * soda4LCA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with soda4LCA.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/


package de.iai.ilcd.webgui.controller.ui;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

import javax.faces.application.FacesMessage;
import javax.faces.bean.ManagedBean;
import javax.faces.context.FacesContext;

import org.primefaces.model.DefaultStreamedContent;
import org.primefaces.model.StreamedContent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.iai.ilcd.configuration.ConfigurationService;

/**
 * 
 * @author clemens.duepmeier
 */
@ManagedBean
public class DownloadAllHandler {
	private Logger logger = LoggerFactory.getLogger("DownloadAllHandler");

	private StreamedContent file;

	public DownloadAllHandler() {

		ConfigurationService confService = new ConfigurationService();
		String zipDirectory = confService.getZipFileDirectory();
		File zipFile = new File(zipDirectory + "/ilcd.zip");
		if (!zipFile.canRead()) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_ERROR,
					"The zip file is currently not available", "");
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
			logger.error("Cannot find zip file {}", zipFile.getAbsoluteFile());
			return;
		}
		try {
			InputStream fileStream = new FileInputStream(zipFile);
			file = new DefaultStreamedContent(fileStream, "application/zip", "ilcd.zip");
		} catch (Exception e) {
			FacesMessage facesMsg = new FacesMessage(FacesMessage.SEVERITY_ERROR,
					"There was some error opening the zip file; please contact the provider", "");
			FacesContext.getCurrentInstance().addMessage("errorInfo", facesMsg);
			logger.error("Cannot open zip file with all data sets");
			return;
		}
	}

	public StreamedContent getFile() {
		return file;
	}

	public void setFile(StreamedContent file) {
		this.file = file;
	}
}
